from distutils.core import setup
setup(
    name="leimolib",
    version="0.0.5",
    description="雷默库",
    author="chenhaoxin",
    author_email="2055709349@qq.com",
    py_modules=['leimeimolib\\lm_jqr','leimolib\\log_in','leimolib\\print_logo_lm','leimolib\\print_one_by_one','leimolib\\ai']
)
